How to Contribute to ncvue
==========================

``ncvue`` development is driven by user feedback, and your contributions help
to find bugs, add features, and improve performance. This is a small guide to
help those who wish to contribute.

We are happy about all contributions! :thumbsup:

Did you find a bug?
-------------------

* Ensure that the bug was not already reported under issue_.
* If the bug was not already reported, open a new issue_ with a clear
  description of the problem and if possible with a minimal `working example`_.
* please add the version number to the issue:

.. code-block:: python

   import ncvue
   print(ncvue.__version__)


Do you have suggestions for new features?
-----------------------------------------

Open a new issue_ with your idea or suggestion and we'd love to discuss about
it.

Do you want to enhance ncvue or fix something?
----------------------------------------------

* Fork the repo on Github_.
* Add yourself to AUTHORS.rst, if you want to.
* Add some tests, if possible.
* Push to your fork and submit a pull request.

.. _Github: https://github.com/mcuntz/ncvue
.. _issue: https://github.com/mcuntz/ncvue/issues
.. _working example: https://en.wikipedia.org/wiki/Minimal_working_example
